Class: Aws::AIOps::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AIOps::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-aiops/client.rb,
sig/client.rbs
Overview
An API client for AIOps. To construct a client, you need to configure a :region and :credentials.
client = Aws::AIOps::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateInvestigationGroupResponseSuccess, _DeleteInvestigationGroupPolicyResponseSuccess, _GetInvestigationGroupPolicyResponseSuccess, _GetInvestigationGroupResponseSuccess, _ListInvestigationGroupsResponseSuccess, _ListTagsForResourceResponseSuccess, _PutInvestigationGroupPolicyResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateInvestigationGroupResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_investigation_group(params = {}) ⇒ Types::CreateInvestigationGroupOutput
Creates an investigation group in your account.
-
#delete_investigation_group(params = {}) ⇒ Struct
Deletes the specified investigation group from your account.
-
#delete_investigation_group_policy(params = {}) ⇒ Struct
Removes the IAM resource policy from being associated with the investigation group that you specify.
-
#get_investigation_group(params = {}) ⇒ Types::GetInvestigationGroupResponse
Returns the configuration information for the specified investigation group.
-
#get_investigation_group_policy(params = {}) ⇒ Types::GetInvestigationGroupPolicyResponse
Returns the JSON of the IAM resource policy associated with the specified investigation group in a string.
-
#list_investigation_groups(params = {}) ⇒ Types::ListInvestigationGroupsOutput
Returns the ARN and name of each investigation group in the account.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Displays the tags associated with a CloudWatch investigations resource.
-
#put_investigation_group_policy(params = {}) ⇒ Types::PutInvestigationGroupPolicyResponse
Creates an IAM resource policy and assigns it to the specified investigation group.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified resource.
-
#update_investigation_group(params = {}) ⇒ Struct
Updates the configuration of the specified investigation group.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-aiops/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1107 1108 1109 |
# File 'lib/aws-sdk-aiops/client.rb', line 1107 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1110 1111 1112 |
# File 'lib/aws-sdk-aiops/client.rb', line 1110 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 |
# File 'lib/aws-sdk-aiops/client.rb', line 1080 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AIOps') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-aiops' context[:gem_version] = '1.19.0' Seahorse::Client::Request.new(handlers, context) end |
#create_investigation_group(params = {}) ⇒ Types::CreateInvestigationGroupOutput
Creates an investigation group in your account. Creating an investigation group is a one-time setup task for each Region in your account. It is a necessary task to be able to perform investigations.
Settings in the investigation group help you centrally manage the common properties of your investigations, such as the following:
-
Who can access the investigations
-
Whether investigation data is encrypted with a customer managed Key Management Service key.
-
How long investigations and their data are retained by default.
Currently, you can have one investigation group in each Region in your account. Each investigation in a Region is a part of the investigation group in that Region
To create an investigation group and set up CloudWatch investigations,
you must be signed in to an IAM principal that has either the
AIOpsConsoleAdminPolicy or the AdministratorAccess IAM policy
attached, or to an account that has similar permissions.
You can configure CloudWatch alarms to start investigations and add
events to investigations. If you create your investigation group with
CreateInvestigationGroup and you want to enable alarms to do this,
you must use PutInvestigationGroupPolicy to create a resource policy
that grants this permission to CloudWatch alarms.
For more information about configuring CloudWatch alarms, see Using Amazon CloudWatch alarms
86 |
# File 'sig/client.rbs', line 86
def create_investigation_group: (
|
#delete_investigation_group(params = {}) ⇒ Struct
Deletes the specified investigation group from your account. You can currently have one investigation group per Region in your account. After you delete an investigation group, you can later create a new investigation group in the same Region.
107 |
# File 'sig/client.rbs', line 107
def delete_investigation_group: (
|
#delete_investigation_group_policy(params = {}) ⇒ Struct
Removes the IAM resource policy from being associated with the investigation group that you specify.
116 |
# File 'sig/client.rbs', line 116
def delete_investigation_group_policy: (
|
#get_investigation_group(params = {}) ⇒ Types::GetInvestigationGroupResponse
Returns the configuration information for the specified investigation group.
138 |
# File 'sig/client.rbs', line 138
def get_investigation_group: (
|
#get_investigation_group_policy(params = {}) ⇒ Types::GetInvestigationGroupPolicyResponse
Returns the JSON of the IAM resource policy associated with the
specified investigation group in a string. For example,
{"Version":"2012-10-17","Statement":[{"Effect":"Allow","Principal":{"Service":"aiops.alarms.cloudwatch.amazonaws.com"},"Action":["aiops:CreateInvestigation","aiops:CreateInvestigationEvent"],"Resource":"*","Condition":{"StringEquals":{"aws:SourceAccount":"111122223333"},"ArnLike":{"aws:SourceArn":"arn:aws:cloudwatch:us-east-1:111122223333:alarm:*"}}}]}.
149 |
# File 'sig/client.rbs', line 149
def get_investigation_group_policy: (
|
#list_investigation_groups(params = {}) ⇒ Types::ListInvestigationGroupsOutput
Returns the ARN and name of each investigation group in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
160 |
# File 'sig/client.rbs', line 160
def list_investigation_groups: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Displays the tags associated with a CloudWatch investigations resource. Currently, investigation groups support tagging.
171 |
# File 'sig/client.rbs', line 171
def list_tags_for_resource: (
|
#put_investigation_group_policy(params = {}) ⇒ Types::PutInvestigationGroupPolicyResponse
Creates an IAM resource policy and assigns it to the specified investigation group.
If you create your investigation group with CreateInvestigationGroup
and you want to enable CloudWatch alarms to create investigations and
add events to investigations, you must use this operation to create a
policy similar to this example.
{ "Version": "2008-10-17", "Statement": [ { "Effect": "Allow", "Principal": { "Service": "aiops.alarms.cloudwatch.amazonaws.com" }, "Action": [ "aiops:CreateInvestigation", "aiops:CreateInvestigationEvent" ], "Resource": "*", "Condition": { "StringEquals": { "aws:SourceAccount": "account-id" }, "ArnLike": { "aws:SourceArn": "arn:aws:cloudwatch:region:account-id:alarm:*" } } } ] }
181 |
# File 'sig/client.rbs', line 181
def put_investigation_group_policy: (
|
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified resource.
Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values.
Tags don't have any semantic meaning to Amazon Web Services and are interpreted strictly as strings of characters.
You can associate as many as 50 tags with a resource.
191 |
# File 'sig/client.rbs', line 191
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified resource.
201 |
# File 'sig/client.rbs', line 201
def untag_resource: (
|
#update_investigation_group(params = {}) ⇒ Struct
Updates the configuration of the specified investigation group.
211 |
# File 'sig/client.rbs', line 211
def update_investigation_group: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1100 1101 1102 |
# File 'lib/aws-sdk-aiops/client.rb', line 1100 def waiter_names [] end |