Class: Aws::AIOps::Types::DeleteInvestigationGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AIOps::Types::DeleteInvestigationGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-aiops/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#identifier ⇒ String
Specify either the name or the ARN of the investigation group that you want to delete.
Instance Attribute Details
#identifier ⇒ String
Specify either the name or the ARN of the investigation group that you want to delete.
206 207 208 209 210 |
# File 'lib/aws-sdk-aiops/types.rb', line 206 class DeleteInvestigationGroupRequest < Struct.new( :identifier) SENSITIVE = [] include Aws::Structure end |